(* $Id: printest.ml,v 1.8 2018/07/30 12:52:20 heinz Exp $
 *
 * GTF (Generic Test Framework): test printer
 * Copyright (C) 2004  Heinz Deinhart
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

let question_generator df = function
    "mucho_question" -> (new Mucho_question.mucho_question df false)#as_question ()
(*   | "word_question" -> (new Word_question.word_question df)#as_question () *)
  | unknown -> raise (Invalid_argument ("Question class: " ^ unknown))

let latex_header =
  "% this latex document was automatically created by GTF\n" ^
  "\n" ^
  "\\documentclass[a4paper]{article}\n" ^
  "\\usepackage[english,german]{babel}\n" ^
  "\\usepackage[latin1]{inputenc}\n" ^
  "\\usepackage[T1]{fontenc}\n" ^
  "\\usepackage{amssymb}\n" ^
  "\\usepackage{a4wide}\n" ^
  "\\usepackage{longtable}\n" ^
  "\\usepackage{amsmath}\n" ^
  "\\usepackage{graphicx}\n" ^
 "\n" ^
  "\\renewcommand{\\labelitemi}{$\\square$}\n" ^
  "\\newcommand{\\tablesep}{&}" ^
  "\n" ^
  "\\begin{document}\n" ^
  "\\setlength{\\parindent}{0mm}" ^
  "\\setlength{\\parskip}{0mm}" ^
  "\n" ^
  "\n"

let latex_footer =
  "\n" ^
  "\\end{document}\n" ^
  "% this latex document was automatically created by GTF\n"

let _ =
  if (Array.length Sys.argv) != 3 then begin
    Printf.fprintf stderr "%s: usage: %s <testfile> {true|false} # do_calc\n"
      Sys.argv.(0) Sys.argv.(0);
    exit 1
  end;
  let test = new Gtf.test question_generator
  and student = new Gtf.student
  and (s, t) = Marshal.from_channel (open_in Sys.argv.(1))
  and calc = bool_of_string Sys.argv.(2)
  in
    student#unarchive s;
    test#unarchive t;
    print_string latex_header;
(* FIXME: latex char escapes *)
    print_string (test#print calc);
    if calc then
      print_string (test#print_calculation ());
    print_string latex_footer
